@@ -10,8 +10,6 @@ import pymupdf
 import gentle_compare
 
 
-pymupdf.TOOLS.set_annot_stem("jorj")
-
 red = (1, 0, 0)
 blue = (0, 0, 1)
 gold = (1, 1, 0)
@@ -226,38 +224,38 @@ def test_1645():
     '''
     Test fix for #1645.
     '''
-    path_in = os.path.abspath( f'{__file__}/../resources/symbol-list.pdf')
-
-    if pymupdf.mupdf_version_tuple >= (1, 25):
-        path_expected = os.path.abspath( f'{__file__}/../../tests/resources/test_1645_expected_1.25.pdf')
-    elif pymupdf.mupdf_version_tuple >= (1, 24, 2):
-        path_expected = os.path.abspath( f'{__file__}/../../tests/resources/test_1645_expected_1.24.2.pdf')
-    elif pymupdf.mupdf_version_tuple >= (1, 24):
-        path_expected = os.path.abspath( f'{__file__}/../../tests/resources/test_1645_expected_1.24.pdf')
-    else:
-        path_expected = os.path.abspath( f'{__file__}/../resources/test_1645_expected_1.22.pdf')
-    path_out = os.path.abspath( f'{__file__}/../test_1645_out.pdf')
-    doc = pymupdf.open(path_in)
-    page = doc[0]
-    page_bounds = page.bound()
-    annot_loc = pymupdf.Rect(page_bounds.x0, page_bounds.y0, page_bounds.x0 + 75, page_bounds.y0 + 15)
-    # Check type of page.derotation_matrix - this is #2911.
-    assert isinstance(page.derotation_matrix, pymupdf.Matrix), \
-            f'Bad type for page.derotation_matrix: {type(page.derotation_matrix)=} {page.derotation_matrix=}.'
-    page.add_freetext_annot(
-            annot_loc * page.derotation_matrix,
-            "TEST",
-            fontsize=18,
-            fill_color=pymupdf.utils.getColor("FIREBRICK1"),
-            rotate=page.rotation,
-            )
-    doc.save(path_out, garbage=1, deflate=True, no_new_id=True)
-    print(f'Have created {path_out}. comparing with {path_expected}.')
-    with open( path_out, 'rb') as f:
-        out = f.read()
-    with open( path_expected, 'rb') as f:
-        expected = f.read()
-    assert out == expected, f'Files differ: {path_out} {path_expected}'
+    # The expected output files assume annot_stem is 'jorj'. We need to always
+    # restore this before returning (this is checked by conftest.py).
+    annot_stem = pymupdf.JM_annot_id_stem
+    pymupdf.TOOLS.set_annot_stem('jorj')
+    try:
+        path_in = os.path.abspath( f'{__file__}/../resources/symbol-list.pdf')
+        path_expected = os.path.abspath( f'{__file__}/../../tests/resources/test_1645_expected.pdf')
+        path_out = os.path.abspath( f'{__file__}/../test_1645_out.pdf')
+        doc = pymupdf.open(path_in)
+        page = doc[0]
+        page_bounds = page.bound()
+        annot_loc = pymupdf.Rect(page_bounds.x0, page_bounds.y0, page_bounds.x0 + 75, page_bounds.y0 + 15)
+        # Check type of page.derotation_matrix - this is #2911.
+        assert isinstance(page.derotation_matrix, pymupdf.Matrix), \
+                f'Bad type for page.derotation_matrix: {type(page.derotation_matrix)=} {page.derotation_matrix=}.'
+        page.add_freetext_annot(
+                annot_loc * page.derotation_matrix,
+                "TEST",
+                fontsize=18,
+                fill_color=pymupdf.utils.getColor("FIREBRICK1"),
+                rotate=page.rotation,
+                )
+        doc.save(path_out, garbage=1, deflate=True, no_new_id=True)
+        print(f'Have created {path_out}. comparing with {path_expected}.')
+        with open( path_out, 'rb') as f:
+            out = f.read()
+        with open( path_expected, 'rb') as f:
+            expected = f.read()
+        assert out == expected, f'Files differ: {path_out} {path_expected}'
+    finally:
+        # Restore annot_stem.
+        pymupdf.TOOLS.set_annot_stem(annot_stem)
 
 def test_1824():
     '''
@@ -479,7 +477,12 @@ def test_4047():
 
 def test_4079():
     path = os.path.normpath(f'{__file__}/../../tests/resources/test_4079.pdf')
-    path_after = os.path.normpath(f'{__file__}/../../tests/resources/test_4079_after.pdf')
+    if pymupdf.mupdf_version_tuple >= (1, 25, 5):
+        path_after = os.path.normpath(f'{__file__}/../../tests/resources/test_4079_after.pdf')
+    else:
+        # 2024-11-27 Expect incorrect behaviour.
+        path_after = os.path.normpath(f'{__file__}/../../tests/resources/test_4079_after_1.25.pdf')
+        
     path_out = os.path.normpath(f'{__file__}/../../tests/test_4079_out')
     with pymupdf.open(path_after) as document_after:
         page = document_after[0]
@@ -502,6 +505,90 @@ def test_4079():
         pixmap_after = page.get_pixmap()
         document.save(f'{path_out}_after.pdf')
         rms = gentle_compare.pixmaps_rms(pixmap_after_expected, pixmap_after)
+        diff = gentle_compare.pixmaps_diff(pixmap_after_expected, pixmap_after)
+        path = os.path.normpath(f'{__file__}/../../tests/test_4079_diff.png')
+        diff.save(path)
         print(f'{rms=}')
-        # 2024-11-27 Expect current broken behaviour.
         assert rms == 0
+
+def test_4254():
+    """Ensure that both annotations are fully created
+
+    We do this by asserting equal top-used colors in respective pixmaps.
+    """
+    doc = pymupdf.open()
+    page = doc.new_page()
+
+    rect = pymupdf.Rect(100, 100, 200, 150)
+    annot = page.add_freetext_annot(rect, "Test Annotation from minimal example")
+    annot.set_border(width=1, dashes=(3, 3))
+    annot.set_opacity(0.5)
+    annot.set_colors(stroke=(1, 0, 0))
+    annot.update()
+
+    rect = pymupdf.Rect(200, 200, 400, 400)
+    annot2 = page.add_freetext_annot(rect, "Test Annotation from minimal example pt 2")
+    annot2.set_border(width=1, dashes=(3, 3))
+    annot2.set_opacity(0.5)
+    annot2.set_colors(stroke=(1, 0, 0))
+    annot2.update()
+
+    # stores top color for each pixmap
+    top_colors = set()
+    for annot in page.annots():
+        pix = annot.get_pixmap()
+        top_colors.add(pix.color_topusage()[1])
+
+    # only one color must exist
+    assert len(top_colors) == 1
+
+def test_richtext():
+    """Test creation of rich text FreeText annotations.
+
+    We create the same annotation on different pages in different ways,
+    with and without using Annotation.update(), and then assert equality
+    of the respective images.
+    """
+    ds = """font-size: 11pt; font-family: sans-serif;"""
+    bullet = chr(0x2610) + chr(0x2611) + chr(0x2612)
+    text = f"""<p style="text-align:justify;margin-top:-25px;">
+    PyMuPDF <span style="color: red;">འདི་ ཡིག་ཆ་བཀྲམ་སྤེལ་གྱི་དོན་ལུ་ པའི་ཐོན་ཐུམ་སྒྲིལ་དྲག་ཤོས་དང་མགྱོགས་ཤོས་ཅིག་ཨིན།</span>
+    <span style="color:blue;">Here is some <b>bold</b> and <i>italic</i> text, followed by <b><i>bold-italic</i></b>. Text-based check boxes: {bullet}.</span>
+    </p>"""
+    gold = (1, 1, 0)
+    doc = pymupdf.open()
+
+    # First page.
+    page = doc.new_page()
+    rect = pymupdf.Rect(100, 100, 350, 200)
+    p2 = rect.tr + (50, 30)
+    p3 = p2 + (0, 30)
+    annot = page.add_freetext_annot(
+        rect,
+        text,
+        fill_color=gold,
+        opacity=0.5,
+        rotate=90,
+        border_width=1,
+        dashes=None,
+        richtext=True,
+        callout=(p3, p2, rect.tr),
+    )
+
+    pix1 = page.get_pixmap()
+
+    # Second page.
+    # the annotation is created with minimal parameters, which are supplied
+    # in a separate call to the .update() method.
+    page = doc.new_page()
+    annot = page.add_freetext_annot(
+        rect,
+        text,
+        border_width=1,
+        dashes=None,
+        richtext=True,
+        callout=(p3, p2, rect.tr),
+    )
+    annot.update(fill_color=gold, opacity=0.5, rotate=90)
+    pix2 = page.get_pixmap()
+    assert pix1.samples == pix2.samples
