@@ -114,7 +114,7 @@ def test_config():
 
 
 def test_glyphnames():
-    name = "infinity"
+    name = "INFINITY"
     infinity = pymupdf.glyph_name_to_unicode(name)
     assert pymupdf.unicode_to_glyph_name(infinity) == name
 
@@ -134,24 +134,32 @@ def test_pdfstring():
 
 def test_open_exceptions():
     try:
-        doc = pymupdf.open(filename, filetype="xps")
+        pymupdf.open(filename, filetype="xps")
     except RuntimeError as e:
         assert repr(e).startswith("FileDataError")
+    else:
+        assert 0
 
     try:
-        doc = pymupdf.open(filename, filetype="xxx")
+        pymupdf.open(filename, filetype="xxx")
     except Exception as e:
         assert repr(e).startswith("ValueError")
+    else:
+        assert 0
 
     try:
-        doc = pymupdf.open("x.y")
+        pymupdf.open("x.y")
     except Exception as e:
         assert repr(e).startswith("FileNotFoundError")
+    else:
+        assert 0
 
     try:
-        doc = pymupdf.open("pdf", b"")
+        pymupdf.open(stream=b"", filetype="pdf")
     except RuntimeError as e:
         assert repr(e).startswith("EmptyFileError")
+    else:
+        assert 0
 
 
 def test_bug1945():
@@ -646,12 +654,8 @@ def test_2553():
     # With mupdf later than 1.23.4, this special page contains no invalid
     # Unicodes.
     #
-    if pymupdf.mupdf_version_tuple > (1, 23, 4):
-        print(f'Checking no occurrence of 0xFFFD, {pymupdf.mupdf_version_tuple=}.')
-        assert chr(0xFFFD) not in set1
-    else:
-        print(f'Checking occurrence of 0xFFFD, {pymupdf.mupdf_version_tuple=}.')
-        assert chr(0xFFFD) in set1
+    print(f'Checking no occurrence of 0xFFFD, {pymupdf.mupdf_version_tuple=}.')
+    assert chr(0xFFFD) not in set1
 
 def test_2553_2():
     doc = pymupdf.open(f"{scriptdir}/resources/test_2553-2.pdf")
@@ -659,11 +663,7 @@ def test_2553_2():
 
     # extract plain text, ensure that there are no 0xFFFD characters
     text = page.get_text()
-    if pymupdf.mupdf_version_tuple >= (1, 23, 7):
-        assert chr(0xfffd) not in text
-    else:
-        # Bug not fixed in MuPDF.
-        assert chr(0xfffd) in text
+    assert chr(0xfffd) not in text
 
 def test_2635():
     """Rendering a page before and after cleaning it should yield the same pixmap."""
@@ -723,15 +723,8 @@ def test_2710():
     assert_rects_approx_eq(page.cropbox, pymupdf.Rect(30.0, 30.0, 565.3200073242188, 811.9199829101562))
     assert_rects_approx_eq(page.mediabox, pymupdf.Rect(0.0, 0.0, 595.3200073242188, 841.9199829101562))
     print(f'test_2710(): {pymupdf.mupdf_version_tuple=}')
-    if pymupdf.mupdf_version_tuple < (1, 23, 5):
-        print(f'test_2710(): Not Checking page.rect and rect.')
-    elif pymupdf.mupdf_version_tuple < (1, 24.0):
-        print(f'test_2710(): Checking page.rect and rect.')
-        assert_rects_approx_eq(page.rect, pymupdf.Rect(0.0, 0.0, 535.3200073242188, 781.9199829101562))
-        assert_rects_approx_eq(rect, pymupdf.Rect(0.7872352600097656, 64.7560043334961, 124.85531616210938, 78.1622543334961))
-    else:
-        # 2023-11-05: Currently broken in mupdf master.
-        print(f'test_2710(): Not Checking page.rect and rect.')
+    # 2023-11-05: Currently broken in mupdf master.
+    print(f'test_2710(): Not Checking page.rect and rect.')
     rebased = hasattr(pymupdf, 'mupdf')
     if rebased:
         wt = pymupdf.TOOLS.mupdf_warnings()
@@ -1321,10 +1314,6 @@ def test_open():
         print('test_open(): not running on classic.')
         return
     
-    if pymupdf.mupdf_version_tuple < (1, 24):
-        print('test_open(): not running on mupdf < 1.24.')
-        return
-    
     import re
     import textwrap
     import traceback
@@ -1609,8 +1598,75 @@ def test_4034():
         page = document[0]
         pixmap2 = document[0].get_pixmap()
     rms = gentle_compare.pixmaps_rms(pixmap1, pixmap2)
-    print(f'Comparison of original/cleaned page 0 pixmaps: {rms=}.')
-    # 2024-11-27: we expect large difference as
-    # https://bugs.ghostscript.com/show_bug.cgi?id=708128 not yet fixed.
-    #
-    assert 30 < rms < 50
+    print(f'test_4034(): Comparison of original/cleaned page 0 pixmaps: {rms=}.')
+    if pymupdf.mupdf_version_tuple < (1, 25, 2):
+        assert 30 < rms < 50
+    else:
+        assert rms == 0
+
+def test_4309():
+    document = pymupdf.open()
+    page = document.new_page()
+    document.delete_page()
+
+def test_4263():
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_4263.pdf')
+    path_out = f'{path}.linerarized.pdf'
+    command = f'pymupdf clean -linear {path} {path_out}'
+    print(f'Running: {command}')
+    cp = subprocess.run(command, shell=1, check=0)
+    if pymupdf.mupdf_version_tuple < (1, 26):
+        assert cp.returncode == 0
+    else:
+        # Support for linerarisation dropped in MuPDF-1.26.
+        assert cp.returncode
+
+def test_4224():
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_4224.pdf')
+    with pymupdf.open(path) as document:
+        for page in document.pages():
+            pixmap = page.get_pixmap(dpi=150)
+            path_pixmap = f'{path}.{page.number}.png'
+            pixmap.save(path_pixmap)
+            print(f'Have created: {path_pixmap}')
+    if pymupdf.mupdf_version_tuple < (1, 25, 5):
+        wt = pymupdf.TOOLS.mupdf_warnings()
+        assert wt == 'format error: negative code in 1d faxd\npadding truncated image'
+
+def test_4319():
+    # Have not seen this test reproduce issue #4319, but keeping it anyway.
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_4319.pdf')
+    doc = pymupdf.open()
+    page = doc.new_page()
+    page.insert_text((10, 100), "some text")
+    doc.save(path)
+    doc.close()
+    doc = pymupdf.open(path)
+    page = doc[0]
+    pc = doc.page_count
+    doc.close()
+    os.remove(path)
+    print(f"removed {doc.name=}")
+
+def test_3886():
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_3886.pdf')
+    path_clean0 = os.path.normpath(f'{__file__}/../../tests/resources/test_3886_clean0.pdf')
+    path_clean1 = os.path.normpath(f'{__file__}/../../tests/resources/test_3886_clean1.pdf')
+    
+    with pymupdf.open(path) as document:
+        pixmap = document[0].get_pixmap()
+        document.save(path_clean0, clean=0)
+    
+    with pymupdf.open(path) as document:
+        document.save(path_clean1, clean=1)
+    
+    with pymupdf.open(path_clean0) as document:
+        pixmap_clean0 = document[0].get_pixmap()
+    
+    with pymupdf.open(path_clean1) as document:
+        pixmap_clean1 = document[0].get_pixmap()
+    
+    rms_0 = gentle_compare.pixmaps_rms(pixmap, pixmap_clean0)
+    rms_1 = gentle_compare.pixmaps_rms(pixmap, pixmap_clean1)
+    print(f'test_3886(): {rms_0=} {rms_1=}')
+        
