@@ -2,12 +2,13 @@
 Define some page labels in a PDF.
 Check success in various aspects.
 """
-import fitz
+
+import pymupdf
 
 
 def make_doc():
     """Makes a PDF with 10 pages."""
-    doc = fitz.open()
+    doc = pymupdf.open()
     for i in range(10):
         page = doc.new_page()
     return doc
@@ -35,6 +36,23 @@ def test_setlabels():
     doc.set_page_labels(make_labels())
     page_labels = [p.get_label() for p in doc]
     answer = ["A-1", "A-2", "A-3", "A-4", "I", "II", "III", "IV", "V", "VI"]
-    assert page_labels == answer, f'page_labels={page_labels}'
+    assert page_labels == answer, f"page_labels={page_labels}"
     assert doc.get_page_numbers("V") == [8]
     assert doc.get_page_labels() == make_labels()
+
+
+def test_labels_styleA():
+    """Test correct indexing for styles "a", "A"."""
+    doc = make_doc()
+    labels = [
+        {"startpage": 0, "prefix": "", "style": "a", "firstpagenum": 1},
+        {"startpage": 5, "prefix": "", "style": "A", "firstpagenum": 1},
+    ]
+    doc.set_page_labels(labels)
+    pdfdata = doc.tobytes()
+    doc.close()
+    doc = pymupdf.open("pdf", pdfdata)
+    answer = ["a", "b", "c", "d", "e", "A", "B", "C", "D", "E"]
+    page_labels = [page.get_label() for page in doc]
+    assert page_labels == answer
+    assert doc.get_page_labels() == labels
