@@ -10,10 +10,13 @@ import gentle_compare
 
 import os
 import platform
+import subprocess
 import sys
 import tempfile
 import pytest
 import textwrap
+import time
+
 
 scriptdir = os.path.abspath(os.path.dirname(__file__))
 epub = os.path.join(scriptdir, "resources", "Bezier.epub")
@@ -164,13 +167,16 @@ def test_3050():
     This is known to fail if MuPDF is built without it's default third-party
     libraries, e.g. in Linux system installs.
     '''
-    pdf_file = pymupdf.open(pdf)
-    for page_no, page in enumerate(pdf_file):
+    path = os.path.normpath(f'{__file__}/../../tests/resources/001003ED.pdf')
+    with pymupdf.open(path) as pdf_file:
+        page_no = 0
+        page = pdf_file[page_no]
         zoom_x = 4.0
         zoom_y = 4.0
         matrix = pymupdf.Matrix(zoom_x, zoom_y)
         pix = page.get_pixmap(matrix=matrix)
-        digest0 = pix.digest
+        path_out = os.path.normpath(f'{__file__}/../../tests/test_3050_out.png')
+        pix.save(path_out)
         print(f'{pix.width=} {pix.height=}')
         def product(x, y):
             for yy in y:
@@ -183,16 +189,18 @@ def test_3050():
             if sum(pix.pixel(pos[0], pos[1])) >= 600:
                 n += 1
                 pix.set_pixel(pos[0], pos[1], (255, 255, 255))
-        digest1 = pix.digest
-        print(f'{page_no=} {n=} {digest0=} {digest1=}')
-        digest_expected = b'\xd7x\x94_\x98\xa1<-/\xf3\xf9\x04\xec#\xaa\xee'
-        pix.save(os.path.abspath(f'{__file__}/../../tests/test_3050_out.png'))
-        assert digest1 != digest0
-        assert digest1 == digest_expected
-        rebased = hasattr(pymupdf, 'mupdf')
-        if rebased:
-            wt = pymupdf.TOOLS.mupdf_warnings()
-            assert wt == 'PDF stream Length incorrect'
+        path_out2 = os.path.normpath(f'{__file__}/../../tests/test_3050_out2.png')
+        pix.save(path_out2)
+        path_expected = os.path.normpath(f'{__file__}/../../tests/resources/test_3050_expected.png')
+        rms = gentle_compare.pixmaps_rms(path_expected, path_out2)
+        print(f'{rms=}')
+        if pymupdf.mupdf_version_tuple < (1, 26):
+            # Slight differences in rendering from fix for mupdf bug 708274.
+            assert rms < 0.2
+        else:
+            assert rms == 0
+        wt = pymupdf.TOOLS.mupdf_warnings()
+        assert wt == 'PDF stream Length incorrect'
 
 def test_3058():
     doc = pymupdf.Document(os.path.abspath(f'{__file__}/../../tests/resources/test_3058.pdf'))
@@ -215,10 +223,6 @@ def test_3058():
     assert 1800000 < s < 2600000, f'Unexpected size of {path}: {s}'
 
 def test_3072():
-    if pymupdf.mupdf_version_tuple < (1, 23, 10):
-        print(f'test_3072(): Not running because known to hang on MuPDF < 1.23.10.')
-        return
-    
     path = os.path.abspath(f'{__file__}/../../tests/resources/test_3072.pdf')
     out = os.path.abspath(f'{__file__}/../../tests')
     
@@ -405,12 +409,18 @@ def test_3448():
         print(f'Have written to: {path_out}')
     path_expected = os.path.normpath(f'{__file__}/../../tests/resources/test_3448.pdf-expected.png')
     pixmap_expected = pymupdf.Pixmap(path_expected)
-    diff = gentle_compare.pixmaps_rms(pixmap, pixmap_expected)
-    print(f'{diff=}')
+    rms = gentle_compare.pixmaps_rms(pixmap, pixmap_expected)
+    diff = gentle_compare.pixmaps_diff(pixmap_expected, pixmap)
+    path_diff = os.path.normpath(f'{__file__}/../../tests/test_3448-diff.png')
+    diff.save(path_diff)
+    print(f'{rms=}')
     if pymupdf.mupdf_version_tuple < (1, 24, 11):
-        assert 30 <= diff < 45
+        assert 30 <= rms < 45
+    elif pymupdf.mupdf_version_tuple < (1, 25, 5):
+        # Prior to fix for mupdf bug 708274.
+        assert 1 < rms < 2
     else:
-        assert 0 <= diff < 0.5
+        assert rms == 0
 
 
 def test_3854():
@@ -423,12 +433,82 @@ def test_3854():
     # 2024-11-29: this is the incorrect expected output.
     path_expected_png = os.path.normpath(f'{__file__}/../../tests/resources/test_3854_expected.png')
     pixmap_expected = pymupdf.Pixmap(path_expected_png)
-    
+    pixmap_diff = gentle_compare.pixmaps_diff(pixmap_expected, pixmap)
+    path_diff = os.path.normpath(f'{__file__}/../../tests/resources/test_3854_diff.png')
+    pixmap_diff.save(path_diff)
     rms = gentle_compare.pixmaps_rms(pixmap, pixmap_expected)
     print(f'{rms=}.')
     if os.environ.get('PYMUPDF_SYSINSTALL_TEST') == '1':
         # MuPDF using external third-party libs gives slightly different
         # behaviour.
-        assert rms < 1
+        assert rms < 2
+    elif pymupdf.mupdf_version_tuple < (1, 25, 5):
+        # # Prior to fix for mupdf bug 708274.
+        assert 0.5 < rms < 2
     else:
         assert rms == 0
+
+
+def test_4155():
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_3854.pdf')
+    with pymupdf.open(path) as document:
+        page = document[0]
+        pixmap = page.get_pixmap()
+        mv = pixmap.samples_mv
+        mvb1 = mv.tobytes()
+    del page
+    del pixmap
+    try:
+        mvb2 = mv.tobytes()
+    except ValueError as e:
+        print(f'Received exception: {e}')
+        assert 'operation forbidden on released memoryview object' in str(e)
+    else:
+        assert 0, f'Did not receive expected exception when using defunct memoryview.'
+
+
+def test_4336():
+    if 0:
+        # Compare with last classic release.
+        import pickle
+        path_out = os.path.normpath(f'{__file__}/../../tests/resources/test_4336_cc')
+        code = textwrap.dedent(f'''
+                import fitz
+                import os
+                import time
+                import pickle
+                
+                path = os.path.normpath(f'{__file__}/../../tests/resources/nur-ruhig.jpg')
+                pixmap = fitz.Pixmap(path)
+                t = time.time()
+                for i in range(10):
+                    cc = pixmap.color_count()
+                t = time.time() - t
+                print(f'test_4336(): {{t=}}')
+                with open({path_out!r}, 'wb') as f:
+                    pickle.dump(cc, f)
+                ''')
+        path_code = os.path.normpath(f'{__file__}/../../tests/resources/test_4336.py')
+        with open(path_code, 'w') as f:
+            f.write(code)
+        venv = os.path.normpath(f'{__file__}/../../tests/resources/test_4336_venv')
+        command = f'{sys.executable} -m venv {venv}'
+        command += f' && . {venv}/bin/activate'
+        command += f' && pip install --force-reinstall pymupdf==1.23.8'
+        command += f' && python {path_code}'
+        print(f'Running: {command}', flush=1)
+        subprocess.run(command, shell=1, check=1)
+        with open(path_out, 'rb') as f:
+            cc_old = pickle.load(f)
+    else:
+        cc_old = None
+    path = os.path.normpath(f'{__file__}/../../tests/resources/nur-ruhig.jpg')
+    pixmap = pymupdf.Pixmap(path)
+    t = time.time()
+    for i in range(10):
+        cc = pixmap.color_count()
+    t = time.time() - t
+    print(f'test_4336(): {t=}')
+    
+    if cc_old:
+        assert cc == cc_old
